/*
 * Copyright (C) 2013 Canonical, Ltd.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 3.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 2.0
import Ubuntu.Components 0.1
import Ubuntu.Components.ListItems 0.1 as ListItem
import Ubuntu.OnlineAccounts 0.1
import Friends 0.1

Rectangle {
    id: post
    width: parent.width
    anchors {
        top: parent.top
        fill: parent
        left: parent.left
        right: parent.right
    }

    FriendsDispatcher {
        id: friends
        onSendComplete: {
             if (success) {
                 activitySpinner.visible = false;
                 post.visible = false;
                 entryArea.text = "";
                 console.log ("Send completed successfully");
             } else {
                 activitySpinner.visible = false;
                 console.log ("Send failed: " + errorMessage);
             }
         }
    }


    Item {
        id: postHeader
        anchors {
            top: parent.top
            left: parent.left
            right: parent.right
            topMargin: units.gu(1)
            leftMargin: units.gu(1)
            rightMargin: units.gu(1)
        }
        height: logo.height + units.gu(1)

        UbuntuShape {
            id: logo
            anchors {
                left: parent.left
                top: parent.top
            }
            width: units.gu(5)
            height: units.gu(5)

            image: Image {
                fillMode: Image.PreserveAspectFit
                source: "images/header_image.png"
                sourceSize.height: logo.height
                sourceSize.width: logo.height
            }
        }

        Label {
            anchors {
                top: parent.top
                left: logo.right
                leftMargin: units.gu(1)
                rightMargin: units.gu(1)
            }

            text: i18n.tr("Share with your friends")
            font.pointSize: 32
            font.weight: Font.DemiBold
        }

        ListItem.Empty {
            id: closeButtonWrapper
            anchors {
                right: parent.right
                top: parent.top
            }
            width: units.gu(4)
            height: units.gu(4)
            showDivider: false
            Text {
                id: closeButton
                text: "×"
                font.pointSize: 32
                font.weight: Font.DemiBold
                font.family: "Ubuntu"
            }
            onClicked: {
                post.visible = false;
            }
        }
    }

    Rectangle {
        id: topLine
        color: "#cccccc"
        height: units.dp(1)
        anchors {
            left: parent.left
            right: parent.right
            top: postHeader.bottom
        }
    }

    Item {
        id: entry
        property var inputEntry: entryArea
        anchors {
            top: topLine.bottom
            left: parent.left
            right: parent.right
            topMargin: units.gu(1)
        }

        MouseArea {
            anchors.fill: entryArea
            onClicked: entryArea.forceActiveFocus()
            z: 1
        }

        TextArea {
            id: entryArea
            anchors {
                left: parent.left
                leftMargin: units.gu(1)
                right: sendButton.left
                rightMargin: units.gu(1)
                bottomMargin: units.gu(1.5)
            }
            focus: true
            font.pixelSize: FontUtils.sizeToPixels("medium")
            font.family: "Ubuntu"
            // send message if return was pressed
            Keys.onReturnPressed: sendButton.clicked(null)
            Keys.onEscapePressed: text = ""
            height: units.gu(4)
            placeholderText: i18n.tr("Compose")
            autoSize: true
            maximumLineCount: 0
        }

        Button {
            id: sendButton
            anchors {
                right: parent.right
                rightMargin: units.gu(1)
                bottom: entryArea.bottom
            }
            width: units.gu(9)
            height: units.gu(4)
            color: "#dd4814"
            text: i18n.tr("Send")
            onClicked: {
                console.log ("Post: " + entryArea.text);
                activitySpinner.visible = true
                friends.sendAsync(entryArea.text);
            }
        }

        ActivityIndicator {
            id: activitySpinner
            anchors.centerIn: entryArea
            visible: false
            running: visible
        }

    }
/*
    AccountServiceModel {
        id: accounts
        serviceType: "microblogging"
    }

    ListView {
        id: accountsView
        width: parent.width
        height: childrenRect.height
        anchors {
            top: entry.bottom
            topMargin: units.gu(2)
        }
        focus: true
        model: accounts
        delegate: Item {
                width: parent.width
                height: childrenRect.height
                AccountService {
                    id: accts
                    objectHandle: accountService
                    Component.onCompleted: {
                        sw.checked = accts.enabled;

                    }
                    onEnabledChanged: {
                        console.log ("ENABLED CHANGED");
                        sw.checked = accts.enabled;
                    }
                }
                ListItem.Standard {
                    text: displayName
                    icon: UbuntuShape {
                        height: units.gu(2)
                        image: Image {
                            fillMode: Image.PreserveAspectFit
                            source: "image://gicon/"+accts.provider.iconName
                        }
                    }
                    control {
                        Switch {
                            id: sw
                            checked: false
                        }
                    }
                    showDivider: false
                }
        }

        populate: Transition {
            NumberAnimation { properties: "x,y"; duration: 1000 }
        }
    }
*/
}

