/*
 * Copyright 2012 Canonical Ltd.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation; version 3.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 2.0
import Ubuntu.Components 0.1
import Ubuntu.Components.ListItems 0.1 as ListItem
import Ubuntu.Components.Popups 0.1
import Friends 0.1

Item {
    id: details
    height: visible ? entryArea.height + threadView.height + units.gu(2) : 0

    property alias hasFocus: entryArea.activeFocus
    onFocusChanged: {
        if (focus && entry && entry.inputEntry) {
            entry.inputEntry.forceActiveFocus()
        }
    }

    FriendsDispatcher {
        id: friends
        onSendComplete: {
             if (success) {
                 activitySpinner.visible = false;
                 entryArea.text = "";
                 console.log ("Send completed successfully");
             } else {
                 activitySpinner.visible = false;
                 console.log ("Send failed: " + errorMessage);
             }
         }
    }

    Item {
        id: threadView
        height: threadLoader.height
        width: parent.width

        anchors {
            top: parent.top
            left: parent.left
            right: parent.right
        }

        Loader {
            id: threadLoader
            width: parent.width
        }

        onVisibleChanged: {
            if (details.visible && threadLoader.state != Loader.Ready) {
                threadLoader.source = "ThreadLoader.qml";
            }
        }
    }

    Item {
        id: entry
        property var inputEntry: entryArea
        anchors {
            top: threadView.bottom
            left: actionArea.right
            right: parent.right
            topMargin: units.gu(2)
        }

        MouseArea {
            anchors.fill: entryArea
            onClicked: entryArea.forceActiveFocus()
            z: 1
        }

        TextArea {
            id: entryArea
            anchors {
                left: parent.left
                leftMargin: units.gu(1)
                right: sendButton.left
                rightMargin: units.gu(1)
                bottomMargin: units.gu(1.5)
            }
            focus: true
            font.pixelSize: FontUtils.sizeToPixels("medium")
            font.family: "Ubuntu"
            // send message if return was pressed
            Keys.onReturnPressed: sendButton.clicked(null)
            Keys.onEscapePressed: text = ""
            height: units.gu(4)
            placeholderText: i18n.tr("Reply")
            autoSize: true
            maximumLineCount: 0
        }

        Button {
            id: sendButton
            anchors {
                right: parent.right
                rightMargin: units.gu(1)
                bottom: entryArea.bottom
            }
            width: units.gu(9)
            height: units.gu(4)
            color: "#dd4814"
            text: i18n.tr("Send")
            onClicked: {
                console.log ("Reply to " + messageId + " from " + accountId + ": " + entryArea.text);
                activitySpinner.visible = true
                friends.sendReplyAsync(accountId, messageId, entryArea.text);
            }
        }

        ActivityIndicator {
            id: activitySpinner
            anchors.centerIn: entryArea
            visible: false
            running: visible
        }
    }

    Item {
        id: actionArea
        anchors {
            right: entry.left
            left: parent.left
        }
        /*
        Image {
            source: "images/gwibber.png"
            asynchronous: true
            fillMode: Image.PreserveAspectFit
        }
        MouseArea {
            anchors.fill: actionArea
            onClicked: {
                console.log ("CLICKED");
                PopupUtils.open(actionPopover, parent)
            }
        }
        */
        ActionPopover {
            id: actionPopover
        }
    }
}
